@@ -17,10 +17,6 @@ from dsocli.utils import set_dict_value
 
 
 default_spec = {
-    'allowGroups': 'no',
-    'prependGroups': 'yes',
-    'groupDelimiter': '/',
-    'nestedDelimiter': '.',
 }
 
 
@@ -55,21 +51,12 @@ class AwsSsmSecretProvider(SecretProvider):
         return output
 
 
-###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
 
     def get_key_validator(self):
 
-        allowGroups = Config.secret_spec('allowGroups')
-        if allowGroups is None:
-            Logger.debug(f"'allowGroups' is not set for the secret provider, defaulted to '{default_spec['allowGroups']}'.")
-            allowGroups = default_spec['allowGroups']
-
-        if allowGroups:
-            return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
-        else:
-            return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
-
+        # return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
+        return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
 
 ###--------------------------------------------------------------------------------------------
 
@@ -102,8 +89,7 @@ class AwsSsmSecretProvider(SecretProvider):
 
 ###--------------------------------------------------------------------------------------------
 
-    def locate_parameter(self, project, application, stage, key, uninherited=False):
-
+    def locate_secret(self, project, application, stage, key, uninherited=False):
         Logger.debug(f"Locating SSM secret: project={project}, application={application}, stage={stage}, key={key}")
         paths = self.get_ssm_search_paths(project, application, stage, key, uninherited)
         Logger.debug(f"SSM paths to search in order: {paths}")
@@ -124,7 +110,7 @@ class AwsSsmSecretProvider(SecretProvider):
             value = secret['Value']
             if key in secrets:
                 Logger.warn("Inherited secret '{0}' overridden.".format(key))
-            secrets[key] = value
+            secrets[key] = {'Value': value, 'Path': path}
         return secrets
 
 ###--------------------------------------------------------------------------------------------
@@ -168,34 +154,14 @@ class AwsSsmSecretProvider(SecretProvider):
     def list(self, project, application, stage, uninherited, decrypt):
         ### construct search path in hierachy with no key specified in reverse order
         paths = list(reversed(self.get_ssm_search_paths(project, application, stage, None, uninherited)))
-        Logger.debug(f"SSM paths to search in order: {paths}")
+        # Logger.debug(f"SSM paths to search in order: {paths}")
         secrets = {}
         for path in paths:
             self.load_ssm_path(secrets, path, decrypt)
 
-        prependGroups = Config.secret_spec('prependGroups')
-        if prependGroups is None:
-            Logger.debug(f"'prependGroups' is not set for the secret provider, defaulted to '{default_spec['prependGroups']}'.")
-            prependGroups = default_spec['prependGroups']
-
-        groupDelimiter = Config.secret_spec('groupDelimiter')
-        if groupDelimiter is None:
-            Logger.debug(f"'groupDelimiter' is not set for the secret provider, defaulted to '{default_spec['groupDelimiter']}'.")
-            groupDelimiter = default_spec['groupDelimiter']
-
-        nestedDelimiter = Config.secret_spec('nestedDelimiter')
-        if nestedDelimiter is None:
-            Logger.debug(f"'nestedDelimiter' is not set for the secret provider, defaulted to '{default_spec['nestedDelimiter']}'.")
-            nestedDelimiter = default_spec['nestedDelimiter']
-
-        Logger.info("Merging secrets...")
-        result = {}
-        for key, value in secrets.items():
-            if prependGroups:
-                key = key.replace('.', nestedDelimiter).replace('/', groupDelimiter)
-            else:
-                key = key.split('/')[-1].replace('.', nestedDelimiter)
-            set_dict_value(result, key.split('.'), value, overwrite_parent=True,  overwrite_children=True)
+        result = {'Secrets': []}
+        for item in secrets.items():
+            result['Secrets'].append({'Key': item[0], 'Value': item[1]['Value'], 'Path': item[1]['Path']})
 
         return result
 
@@ -203,24 +169,25 @@ class AwsSsmSecretProvider(SecretProvider):
 
     def add(self, project, application, stage, key, value):
         self.assert_no_scope_overwrites(project, application, stage, key)
-        found = self.locate_parameter(project, application, stage, key, True)
+        found = self.locate_secret(project, application, stage, key, True)
         if found and len(found) > 0 and not found[0]['Type'] in ['SecureString']:
-            raise DSOException(f"Failed to add secret '{key}' becasue there is already a SSM parameter with the same key in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+            raise DSOException(f"Failed to add secret '{key}' becasue there is already a SSM parameter with the same key in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         path = self.get_secret_prefix(project, application, stage=stage, key=key)
         Logger.info(f"Adding SSM secret: path={path}")
         ssm.put_parameter(Name=path, Value=value, Type='SecureString', Overwrite=True)
+        return path
 
 ###--------------------------------------------------------------------------------------------
 
     def get(self, project, application, stage, key):
-        found = self.locate_parameter(project, application, stage, key)
+        found = self.locate_secret(project, application, stage, key)
         if not found or len(found) == 0:
-                raise DSOException(f"Secret '{key}' not found nor inherited in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Secret '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             # if len(found) > 1:
             #     Logger.warn(f"More than one secret found at '{found[0]['Name']}'. The first one taken, and the rest were discarded.")
             if not found[0]['Type'] in ['SecureString']:
-                raise DSOException(f"Secret '{key}' not found nor inherited in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Secret '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found[0]['Name']}")
         result = ssm.get_parameter(Name=found[0]['Name'], WithDecryption=True)
         return result['Parameter']['Value']
@@ -229,16 +196,17 @@ class AwsSsmSecretProvider(SecretProvider):
 
     def delete(self, project, application, stage, key):
         ### only secrets owned by the stage can be deleted, hence uninherited=True
-        found = self.locate_parameter(project, application, stage, key, uninherited=True)
+        found = self.locate_secret(project, application, stage, key, uninherited=True)
         if not found or len(found) == 0:
-                raise DSOException(f"Secret not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Secret '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             # if len(found) > 1:
             #     Logger.warn(f"More than one secret found at '{found[0]['Name']}'. The first one taken, and the rest were discarded.")
             if not found[0]['Type'] in ['SecureString']:
-                raise DSOException(f"Secret not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Secret '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM secret: path={found[0]['Name']}")
         ssm.delete_parameter(Name=found[0]['Name'])
+        return found[0]['Name']
 
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
