@@ -31,6 +31,7 @@ class SecretsClass():
         return provider.list(project, application, stage, uninherited, decrypt)
 
     def add(self, stage, key, value):
+        self.validate_key(key)
         project = Config.project
         application = Config.application
         provider = ProviderManager.SecretProvider()
@@ -38,6 +39,7 @@ class SecretsClass():
         return provider.add(project, application, stage, key, value)
 
     def get(self, stage, key):
+        # self.validate_key(key)
         project = Config.project
         application = Config.application
         provider = ProviderManager.SecretProvider()
@@ -45,6 +47,7 @@ class SecretsClass():
         return provider.get(project, application, stage, key)
 
     def delete(self, stage, key):
+        # self.validate_key(key)
         project = Config.project
         application = Config.application
         provider = ProviderManager.SecretProvider()
